@@ -31,7 +31,7 @@ CONFIG = {
 
 
 # used for testing
-_MESSAGES = list()
+_MESSAGES = []
 
 # so that we don't re-compute this variable over
 # and over again:
@@ -113,7 +113,6 @@ darkred = red
 darkgreen = green
 darkblue = blue
 purple = magenta
-fuscia = magenta
 fuschia = magenta
 turquoise = cyan
 darkgray = black
@@ -187,7 +186,7 @@ def process_tokens(
     """
     # Flatten the list of tokens in case some of them are of
     # class UnicodeSequence:
-    flat_tokens = list()  # type: List[Token]
+    flat_tokens = []  # type: List[Token]
     for token in tokens:
         if isinstance(token, UnicodeSequence):
             flat_tokens.extend(token.tuple())
@@ -226,7 +225,7 @@ def write_and_flush(fileobj: FileObj, to_write: str) -> None:
     try:
         fileobj.write(to_write)
     except UnicodeEncodeError:
-        # Maybe the file descritor does not support the full Unicode
+        # Maybe the file descriptor does not support the full Unicode
         # set, like stdout on Windows.
         # Use the unidecode library
         # to make sure we only have ascii, while still keeping
@@ -253,10 +252,15 @@ def message(
     write_and_flush(fileobj, to_write)
 
 
-def fatal(*tokens: Token, **kwargs: Any) -> None:
-    """Print an error message and call ``sys.exit``"""
+def fatal(*tokens: Token, exit_code: int = 1, **kwargs: Any) -> None:
+    """Print an error message and exit the program
+
+    :param tokens: list of `ui` constants or strings, like
+                   ``(cli_ui.red, "this is a fatal  error")``
+    :param exit_code: value of the exit code (default: 1)
+    """
     error(*tokens, **kwargs)
-    sys.exit(1)
+    sys.exit(exit_code)
 
 
 def error(*tokens: Token, **kwargs: Any) -> None:
@@ -385,11 +389,11 @@ def info_table(
     data: Any, *, headers: Union[str, Sequence[str]] = (), fileobj: FileObj = sys.stdout
 ) -> None:
     if headers == "keys":
-        colored_data: Any = dict()
-        plain_data: Any = dict()
+        colored_data: Any = {}
+        plain_data: Any = {}
         for key, sequence in data.items():
-            colored_sequence = list()
-            plain_sequence = list()
+            colored_sequence = []
+            plain_sequence = []
             for item in sequence:
                 colored_str, plain_str = process_tokens(item, end="")
                 colored_sequence.append(colored_str)
@@ -398,11 +402,11 @@ def info_table(
             colored_data[colored_key] = colored_sequence
             plain_data[plain_key] = plain_sequence
     else:
-        colored_data = list()
-        plain_data = list()
+        colored_data = []
+        plain_data = []
         for row in data:
-            colored_row = list()
-            plain_row = list()
+            colored_row = []
+            plain_row = []
             for item in row:
                 colored_str, plain_str = process_tokens(item, end="")
                 colored_row.append(colored_str)
