@@ -106,7 +106,7 @@ def test_info_stdout_no_colors(dumb_tty: DumbTTY) -> None:
 
 def test_info_characters(always_color: None, smart_tty: SmartTTY) -> None:
     cli_ui.info(
-        "Doing stuff", cli_ui.ellipsis, "sucess", cli_ui.check, fileobj=smart_tty
+        "Doing stuff", cli_ui.ellipsis, "success", cli_ui.check, fileobj=smart_tty
     )
     actual = smart_tty.getvalue()
     if os.name == "nt":
@@ -115,7 +115,7 @@ def test_info_characters(always_color: None, smart_tty: SmartTTY) -> None:
     else:
         success = "✓"
         ellipsis = "…"
-    expected = f"Doing stuff {RESET_ALL}{RESET_ALL}{ellipsis} {RESET_ALL}sucess {RESET_ALL}{GREEN}{success} {RESET_ALL}\n{RESET_ALL}"
+    expected = f"Doing stuff {RESET_ALL}{RESET_ALL}{ellipsis} {RESET_ALL}success {RESET_ALL}{GREEN}{success} {RESET_ALL}\n{RESET_ALL}"
     assert actual == expected
 
 
@@ -331,6 +331,20 @@ def test_quiet(message_recorder: MessageRecorder) -> None:
     assert not message_recorder.find("info")
 
 
+def test_fatal() -> None:
+    cli_ui.setup(quiet=True)
+    with pytest.raises(SystemExit) as e:
+        cli_ui.fatal("default exit code")
+    assert e.value.code == 1
+
+
+def test_fatal_with_custom_code() -> None:
+    cli_ui.setup(quiet=True)
+    with pytest.raises(SystemExit) as e:
+        cli_ui.fatal("custom exit code", exit_code=3)
+    assert e.value.code == 3
+
+
 def test_color_always(dumb_tty: DumbTTY) -> None:
     cli_ui.setup(color="always")
     cli_ui.info(cli_ui.red, "this is red", fileobj=dumb_tty)
